==> bitfront-library-6.0.0.tgz: package/src/app/app.module.ts <==
import {Injector,
        NgModule}                 from '@angular/core';
import {LocationStrategy,
        HashLocationStrategy}     from '@angular/common';
import {BrowserAnimationsModule}  from '@angular/platform-browser/animations';        
import {BrowserModule}            from '@angular/platform-browser';
import {APP_BASE_HREF}            from '@angular/common';
import { ActivatedRouteSnapshot, RouterStateSnapshot } from '@angular/router';

import {AppComponent}             from './app.component';
import {CommonModule}             from './common/common.module';
import {HomeModule}               from './home/home.module';
import {TestModule}               from './test/test.module';
import {SharedModule}             from './shared/shared.module';
import {DeveloperModule}          from './developer/developer.module';
import {routing}                  from './app.routing';
import {LocatorService}           from './shared/index';
import {environment}              from '../environments/environment';

@NgModule({
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    routing,
    CommonModule,
    HomeModule,
    TestModule,
    SharedModule,
    DeveloperModule
  ],
  declarations: [ AppComponent ],
  providers: [
    {
        provide: 'externalUrlRedirectResolver',
        useValue: (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        {
            alert("modulo no existe");
        }
    }
  ],
  bootstrap: [ AppComponent ] //que componente arrancará al iniciar la app
})
export class AppModule { 
    constructor(injector: Injector){      
      console.log(`AppModule construido para ${environment.entorno}`)
      LocatorService.injector = injector;
    }    
}

==> bitfront-library-6.6.2.tgz: package/src/app/app.module.ts <==
import {Injector,
        NgModule}                 from '@angular/core';
import {LocationStrategy,
        HashLocationStrategy}     from '@angular/common';
import {BrowserAnimationsModule}  from '@angular/platform-browser/animations';        
import {BrowserModule}            from '@angular/platform-browser';
import { ActivatedRouteSnapshot, RouterStateSnapshot } from '@angular/router';

import {LocatorService}           from './shared/service/locator.service';
import {AppComponent}             from './app.component';
import {CommonModule}             from './common/common.module';
import {HomeModule}               from './home/home.module';
import {TestModule}               from './test/test.module';
import {SharedModule}             from './shared/shared.module';
import {DeveloperModule}          from './developer/developer.module';
import {routing}                  from './app.routing';
import {environment}              from '../environments/environment';
import {AyudaService}             from './shared/service/ayuda.service';
import {AYUDAS_FORM}              from './app.ayudas'; 


@NgModule({
  imports: [
    BrowserModule,
    BrowserAnimationsModule,
    routing,
    CommonModule,
    HomeModule,
    TestModule,
    SharedModule,
    DeveloperModule
  ],
  declarations: [ AppComponent ],
  providers: [
    {
        provide: 'externalUrlRedirectResolver',
        useValue: (route: ActivatedRouteSnapshot, state: RouterStateSnapshot) =>
        {
            alert("modulo no existe");
        }
    }
  ],
  bootstrap: [ AppComponent ] //que componente arrancará al iniciar la app
})
export class AppModule { 
    constructor(injector: Injector){      
      console.log(`AppModule construido para ${environment.entorno}`)
      LocatorService.injector = injector;
      AyudaService.AYUDAS = AYUDAS_FORM;
    }    
}
